==> handy_ui_kit-0.0.17.tar.gz: lib/src/MyCircularTimer.dart <==
import 'package:flutter/material.dart';
import 'dart:math' as Math;

class MyCircularTimer extends StatelessWidget {
  final Color backgroundColor;
  final Color foregroundColor;
  final Color fillColor;
  final Color emptyColor;
  final double value;
  final double size;

  const MyCircularTimer({
    Key key,
    this.backgroundColor,
    this.fillColor = Colors.black,
    this.emptyColor = Colors.grey,
    @required this.foregroundColor,
    @required this.value,
    @required this.size,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final backgroundColor = this.backgroundColor;
    final foregroundColor = this.foregroundColor;
    return Stack(
      children: <Widget>[
        AspectRatio(
          aspectRatio: 1,
          child: CustomPaint(
            child: Container(
              child: Text("ssadasdasdas"),
            ),
            foregroundPainter: CircleProgressBarPainter(
                backgroundColor: backgroundColor,
                foregroundColor: foregroundColor,
                fillColor: fillColor,
                emptyColor: emptyColor,
                percentage: this.value,
                value: this.value),
          ),
        ),
        Container(
          width: size,
          height: size,
          child: Center(
              child: Text(
            value.round().toString(),
            style: TextStyle(fontSize: 130),
          )),
        )
      ],
    );
  }
}

class CircleProgressBarPainter extends CustomPainter {
  final double percentage;
  final double strokeWidth;
  final double value;
  final Color backgroundColor;
  final Color foregroundColor;
  final Color fillColor;
  final Color emptyColor;

  CircleProgressBarPainter({
    this.backgroundColor,
    @required this.foregroundColor,
    @required this.fillColor,
    @required this.emptyColor,
    @required this.percentage,
    @required this.value,
    double strokeWidth,
  }) : this.strokeWidth = strokeWidth ?? 6;

  @override
  void paint(Canvas canvas, Size size) {
    final Offset center = size.center(Offset.zero);
    final Size constrainedSize = size - Offset(this.strokeWidth, this.strokeWidth);
    final shortestSide = Math.min(constrainedSize.width, constrainedSize.height);
    final foregroundPaint = Paint()
      ..color = emptyColor
      ..strokeWidth = 5
      ..strokeCap = StrokeCap.square
      ..style = PaintingStyle.stroke;

    final foregroundPaint2 = Paint()
      ..color = fillColor
      ..strokeWidth = 5
      ..strokeCap = StrokeCap.square
      ..style = PaintingStyle.stroke;

    final radius = (shortestSide * 0.8);
    var path2 = Path();

    if (this.backgroundColor != null) {
      final backgroundPaint = Paint()
        ..color = backgroundColor
        ..strokeWidth = this.strokeWidth
        ..style = PaintingStyle.fill;
      canvas.drawCircle(center, radius * 1.015, backgroundPaint);
    }

    for (var i = 2; i < 1200; i++) {
      if (i % 20 == 0) {
        canvas.drawArc(
          Rect.fromCircle(center: center, radius: radius),
          (-2 * Math.pi / 4) + (i * 2 * Math.pi / 118),
          (Math.pi / radius),
          true,
          foregroundPaint,
        );
      }
    }

    for (var i = 2; i < value * 2; i++) {
      if (i % 2 == 0) {
        canvas.drawArc(
          Rect.fromCircle(center: center, radius: radius),
          (-2 * Math.pi / 4) + (i * 2 * Math.pi / 118),
          (Math.pi / radius),
          true,
          foregroundPaint2,
        );
      }
    }

    if (this.backgroundColor != null) {
      final backgroundPaint = Paint()
        ..color = backgroundColor
        ..strokeWidth = this.strokeWidth
        ..style = PaintingStyle.fill;
      canvas.drawCircle(center, radius * 0.85, backgroundPaint);
    }

    canvas.drawPath(path2, foregroundPaint2);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    final oldPainter = (oldDelegate as CircleProgressBarPainter);
    return oldPainter.percentage != this.percentage ||
        oldPainter.backgroundColor != this.backgroundColor ||
        oldPainter.foregroundColor != this.foregroundColor ||
        oldPainter.strokeWidth != this.strokeWidth;
  }
}

class LineDashedPainter extends CustomPainter {
  @override
  void paint(Canvas canvas, Size size) {
    var paint = Paint()..strokeWidth = 2;
    var max = 35;
    var dashWidth = 5;
    var dashSpace = 5;
    double startY = 0;
    while (max >= 0) {
      canvas.drawLine(Offset(0, startY), Offset(0, startY + dashWidth), paint);
      final space = (dashSpace + dashWidth);
      startY += space;
      max -= space;
    }
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) => false;
}

==> handy_ui_kit-0.0.41.tar.gz: lib/src/MyCircularTimer.dart <==
import 'package:flutter/material.dart';
import 'dart:math' as Math;

class MyCircularTimer extends StatelessWidget {
  final Color backgroundColor;
  final Color foregroundColor;
  final Color fillColor;
  final Color emptyColor;
  final double value;
  final double size;

  const MyCircularTimer({
    required this.backgroundColor,
    this.fillColor = Colors.black,
    this.emptyColor = Colors.grey,
    required this.foregroundColor,
    required this.value,
    required this.size,
  });

  @override
  Widget build(BuildContext context) {
    final backgroundColor = this.backgroundColor;
    final foregroundColor = this.foregroundColor;
    return Stack(
      children: <Widget>[
        AspectRatio(
          aspectRatio: 1,
          child: CustomPaint(
            child: Container(
              child: Text("ssadasdasdas"),
            ),
            foregroundPainter: CircleProgressBarPainter(
                backgroundColor: backgroundColor,
                foregroundColor: foregroundColor,
                fillColor: fillColor,
                emptyColor: emptyColor,
                percentage: this.value,
                value: this.value),
          ),
        ),
        Container(
          width: size,
          height: size,
          child: Center(
              child: Text(
            value.round().toString(),
            style: TextStyle(fontSize: 130),
          )),
        )
      ],
    );
  }
}

class CircleProgressBarPainter extends CustomPainter {
  final double percentage;
  final double strokeWidth;
  final double value;
  final Color backgroundColor;
  final Color foregroundColor;
  final Color fillColor;
  final Color emptyColor;

  CircleProgressBarPainter( {
    required this.backgroundColor,
    required this.foregroundColor,
    required this.fillColor,
    required this.emptyColor,
    required this.percentage,
    required this.value,
    this.strokeWidth=6,
  });

  @override
  void paint(Canvas canvas, Size size) {
    final Offset center = size.center(Offset.zero);
    final Size constrainedSize = Size(size.width -this.strokeWidth,size.height- this.strokeWidth);
    final shortestSide = Math.min(constrainedSize.width, constrainedSize.height);
    final foregroundPaint = Paint()
      ..color = emptyColor
      ..strokeWidth = 5
      ..strokeCap = StrokeCap.square
      ..style = PaintingStyle.stroke;

    final foregroundPaint2 = Paint()
      ..color = fillColor
      ..strokeWidth = 5
      ..strokeCap = StrokeCap.square
      ..style = PaintingStyle.stroke;

    final radius = (shortestSide * 0.8);
    var path2 = Path();

    if (this.backgroundColor != null) {
      final backgroundPaint = Paint()
        ..color = backgroundColor
        ..strokeWidth = this.strokeWidth
        ..style = PaintingStyle.fill;
      canvas.drawCircle(center, radius * 1.015, backgroundPaint);
    }

    for (var i = 2; i < 1200; i++) {
      if (i % 20 == 0) {
        canvas.drawArc(
          Rect.fromCircle(center: center, radius: radius),
          (-2 * Math.pi / 4) + (i * 2 * Math.pi / 118),
          (Math.pi / radius),
          true,
          foregroundPaint,
        );
      }
    }

    for (var i = 2; i < value * 2; i++) {
      if (i % 2 == 0) {
        canvas.drawArc(
          Rect.fromCircle(center: center, radius: radius),
          (-2 * Math.pi / 4) + (i * 2 * Math.pi / 118),
          (Math.pi / radius),
          true,
          foregroundPaint2,
        );
      }
    }

    if (this.backgroundColor != null) {
      final backgroundPaint = Paint()
        ..color = backgroundColor
        ..strokeWidth = this.strokeWidth
        ..style = PaintingStyle.fill;
      canvas.drawCircle(center, radius * 0.85, backgroundPaint);
    }

    canvas.drawPath(path2, foregroundPaint2);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    final oldPainter = (oldDelegate as CircleProgressBarPainter);
    return oldPainter.percentage != this.percentage ||
        oldPainter.backgroundColor != this.backgroundColor ||
        oldPainter.foregroundColor != this.foregroundColor ||
        oldPainter.strokeWidth != this.strokeWidth;
  }
}

class LineDashedPainter extends CustomPainter {
  @override
  void paint(Canvas canvas, Size size) {
    var paint = Paint()..strokeWidth = 2;
    var max = 35;
    var dashWidth = 5;
    var dashSpace = 5;
    double startY = 0;
    while (max >= 0) {
      canvas.drawLine(Offset(0, startY), Offset(0, startY + dashWidth), paint);
      final space = (dashSpace + dashWidth);
      startY += space;
      max -= space;
    }
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) => false;
}
